@@ -35,8 +35,8 @@ protected:
   vtkIOParallelExodusObjectFactory();
 
 private:
-  vtkIOParallelExodusObjectFactory(const vtkIOParallelExodusObjectFactory&); // Not implemented
-  void operator=(const vtkIOParallelExodusObjectFactory&);      // Not implemented
+  vtkIOParallelExodusObjectFactory(const vtkIOParallelExodusObjectFactory&) VTK_DELETE_FUNCTION;
+  void operator=(const vtkIOParallelExodusObjectFactory&) VTK_DELETE_FUNCTION;
 };
 
 #endif // __vtkIOParallelExodusObjectFactory_h
