@@ -27,6 +27,26 @@ public class vtkContextClip extends vtkAbstractContextItem
   public void SetClip(double id0,double id1,double id2,double id3)
     { SetClip_4(id0,id1,id2,id3); }
 
+  private native void GetRect_5(double id0[]);
+  public void GetRect(double id0[])
+    { GetRect_5(id0); }
+
+  private native double GetX_6();
+  public double GetX()
+    { return GetX_6(); }
+
+  private native double GetY_7();
+  public double GetY()
+    { return GetY_7(); }
+
+  private native double GetWidth_8();
+  public double GetWidth()
+    { return GetWidth_8(); }
+
+  private native double GetHeight_9();
+  public double GetHeight()
+    { return GetHeight_9(); }
+
   public vtkContextClip() { super(); }
 
   public vtkContextClip(long id) { super(id); }
