@@ -39,13 +39,21 @@ public class vtkIdTypeArray extends vtkDataArray
   public int InsertNextValue(int id0)
     { return InsertNextValue_7(id0); }
 
-  private native int GetDataTypeValueMin_8();
-  public int GetDataTypeValueMin()
-    { return GetDataTypeValueMin_8(); }
+  private native long FastDownCast_8(vtkAbstractArray id0);
+  public vtkIdTypeArray FastDownCast(vtkAbstractArray id0) {
+    long temp = FastDownCast_8(id0);
 
-  private native int GetDataTypeValueMax_9();
+    if (temp == 0) return null;
+    return (vtkIdTypeArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
+}
+
+  private native int GetDataTypeValueMin_9();
+  public int GetDataTypeValueMin()
+    { return GetDataTypeValueMin_9(); }
+
+  private native int GetDataTypeValueMax_10();
   public int GetDataTypeValueMax()
-    { return GetDataTypeValueMax_9(); }
+    { return GetDataTypeValueMax_10(); }
 
   public vtkIdTypeArray() { super(); }
 
