@@ -16,135 +16,147 @@ import java.io.File;
  */
 public enum vtkNativeLibrary {
 
-    VTKINFOVISCORE("vtkInfovisCoreJava", true),
-    VTKINFOVISLAYOUT("vtkInfovisLayoutJava", true),
-    VTKINFOVISPARALLEL("vtkInfovisParallelJava", false),
-    VTKINFOVISBOOSTGRAPHALGORITHMS("vtkInfovisBoostGraphAlgorithmsJava", true),
-    VTKDOMAINSCHEMISTRYOPENGL2("vtkDomainsChemistryOpenGL2Java", false),
-    VTKDOMAINSCHEMISTRY("vtkDomainsChemistryJava", true),
-    VTKINTERACTIONWIDGETS("vtkInteractionWidgetsJava", true),
-    VTKINTERACTIONIMAGE("vtkInteractionImageJava", true),
-    VTKINTERACTIONSTYLE("vtkInteractionStyleJava", true),
-    VTKCOMMONSYSTEM("vtkCommonSystemJava", true),
+    VTKACCELERATORSDAX("vtkAcceleratorsDaxJava", false),
+    VTKACCELERATORSPISTON("vtkAcceleratorsPistonJava", false),
+    VTKCHARTSCORE("vtkChartsCoreJava", true),
+    VTKCOMMONCOLOR("vtkCommonColorJava", true),
+    VTKCOMMONCOMPUTATIONALGEOMETRY("vtkCommonComputationalGeometryJava", true),
     VTKCOMMONCORE("vtkCommonCoreJava", true),
     VTKCOMMONDATAMODEL("vtkCommonDataModelJava", true),
     VTKCOMMONEXECUTIONMODEL("vtkCommonExecutionModelJava", true),
-    VTKCOMMONCOMPUTATIONALGEOMETRY("vtkCommonComputationalGeometryJava", true),
-    VTKCOMMONMISC("vtkCommonMiscJava", true),
-    VTKCOMMONCOLOR("vtkCommonColorJava", true),
     VTKCOMMONMATH("vtkCommonMathJava", true),
+    VTKCOMMONMISC("vtkCommonMiscJava", true),
+    VTKCOMMONSYSTEM("vtkCommonSystemJava", true),
     VTKCOMMONTRANSFORMS("vtkCommonTransformsJava", true),
-    VTKIMAGINGCORE("vtkImagingCoreJava", true),
-    VTKIMAGINGMORPHOLOGICAL("vtkImagingMorphologicalJava", true),
-    VTKIMAGINGGENERAL("vtkImagingGeneralJava", true),
-    VTKIMAGINGFOURIER("vtkImagingFourierJava", true),
-    VTKIMAGINGSOURCES("vtkImagingSourcesJava", true),
-    VTKIMAGINGHYBRID("vtkImagingHybridJava", true),
-    VTKIMAGINGSTENCIL("vtkImagingStencilJava", true),
-    VTKIMAGINGCOLOR("vtkImagingColorJava", true),
-    VTKIMAGINGMATH("vtkImagingMathJava", true),
-    VTKIMAGINGSTATISTICS("vtkImagingStatisticsJava", true),
-    VTKGEOVISCORE("vtkGeovisCoreJava", true),
-    VTKRENDERINGCORE("vtkRenderingCoreJava", true),
-    VTKRENDERINGCONTEXTOPENGL("vtkRenderingContextOpenGLJava", true),
-    VTKRENDERINGVOLUMEAMR("vtkRenderingVolumeAMRJava", true),
-    VTKRENDERINGVOLUME("vtkRenderingVolumeJava", true),
-    VTKRENDERINGEXTERNAL("vtkRenderingExternalJava", false),
-    VTKRENDERINGVOLUMEOPENGL2("vtkRenderingVolumeOpenGL2Java", false),
-    VTKRENDERINGOPENGL2("vtkRenderingOpenGL2Java", false),
-    VTKRENDERINGLICOPENGL2("vtkRenderingLICOpenGL2Java", false),
-    VTKRENDERINGVOLUMEOPENGL("vtkRenderingVolumeOpenGLJava", true),
-    VTKRENDERINGANNOTATION("vtkRenderingAnnotationJava", true),
-    VTKRENDERINGQT("vtkRenderingQtJava", true),
-    VTKRENDERINGCONTEXTOPENGL2("vtkRenderingContextOpenGL2Java", false),
-    VTKRENDERINGLOD("vtkRenderingLODJava", true),
-    VTKRENDERINGOPENGL("vtkRenderingOpenGLJava", true),
-    VTKRENDERINGCONTEXT2D("vtkRenderingContext2DJava", true),
-    VTKRENDERINGGL2PS("vtkRenderingGL2PSJava", true),
-    VTKRENDERINGLABEL("vtkRenderingLabelJava", true),
-    VTKRENDERINGFREETYPE("vtkRenderingFreeTypeJava", true),
-    VTKRENDERINGPARALLEL("vtkRenderingParallelJava", true),
-    VTKRENDERINGMATPLOTLIB("vtkRenderingMatplotlibJava", true),
-    VTKRENDERINGIMAGE("vtkRenderingImageJava", true),
-    VTKRENDERINGPARALLELLIC("vtkRenderingParallelLICJava", true),
-    VTKRENDERINGLIC("vtkRenderingLICJava", true),
-    VTKCHARTSCORE("vtkChartsCoreJava", true),
-    VTKFILTERSPYTHON("vtkFiltersPythonJava", true),
-    VTKFILTERSMODELING("vtkFiltersModelingJava", true),
-    VTKFILTERSCORE("vtkFiltersCoreJava", true),
-    VTKFILTERSPARALLELIMAGING("vtkFiltersParallelImagingJava", true),
-    VTKFILTERSGENERAL("vtkFiltersGeneralJava", true),
-    VTKFILTERSIMAGING("vtkFiltersImagingJava", true),
+    VTKDOMAINSCHEMISTRY("vtkDomainsChemistryJava", true),
+    VTKDOMAINSCHEMISTRYOPENGL2("vtkDomainsChemistryOpenGL2Java", true),
+    VTKDOMAINSMICROSCOPY("vtkDomainsMicroscopyJava", false),
     VTKFILTERSAMR("vtkFiltersAMRJava", true),
-    VTKFILTERSSOURCES("vtkFiltersSourcesJava", true),
-    VTKFILTERSHYBRID("vtkFiltersHybridJava", true),
-    VTKFILTERSREEBGRAPH("vtkFiltersReebGraphJava", true),
-    VTKFILTERSGENERIC("vtkFiltersGenericJava", true),
-    VTKFILTERSPARALLELSTATISTICS("vtkFiltersParallelStatisticsJava", true),
-    VTKFILTERSVERDICT("vtkFiltersVerdictJava", true),
-    VTKFILTERSHYPERTREE("vtkFiltersHyperTreeJava", true),
-    VTKFILTERSFLOWPATHS("vtkFiltersFlowPathsJava", true),
-    VTKFILTERSSELECTION("vtkFiltersSelectionJava", true),
-    VTKFILTERSTEXTURE("vtkFiltersTextureJava", true),
-    VTKFILTERSPARALLELGEOMETRY("vtkFiltersParallelGeometryJava", true),
-    VTKFILTERSPARALLEL("vtkFiltersParallelJava", true),
-    VTKFILTERSPROGRAMMABLE("vtkFiltersProgrammableJava", true),
-    VTKFILTERSPARALLELFLOWPATHS("vtkFiltersParallelFlowPathsJava", true),
-    VTKFILTERSSTATISTICSGNUR("vtkFiltersStatisticsGnuRJava", false),
+    VTKFILTERSCORE("vtkFiltersCoreJava", true),
     VTKFILTERSEXTRACTION("vtkFiltersExtractionJava", true),
+    VTKFILTERSFLOWPATHS("vtkFiltersFlowPathsJava", true),
+    VTKFILTERSGENERAL("vtkFiltersGeneralJava", true),
+    VTKFILTERSGENERIC("vtkFiltersGenericJava", true),
     VTKFILTERSGEOMETRY("vtkFiltersGeometryJava", true),
-    VTKFILTERSSTATISTICS("vtkFiltersStatisticsJava", true),
+    VTKFILTERSHYBRID("vtkFiltersHybridJava", true),
+    VTKFILTERSHYPERTREE("vtkFiltersHyperTreeJava", true),
+    VTKFILTERSIMAGING("vtkFiltersImagingJava", true),
+    VTKFILTERSMODELING("vtkFiltersModelingJava", true),
+    VTKFILTERSPARALLEL("vtkFiltersParallelJava", true),
+    VTKFILTERSPARALLELDIY2("vtkFiltersParallelDIY2Java", true),
+    VTKFILTERSPARALLELFLOWPATHS("vtkFiltersParallelFlowPathsJava", true),
+    VTKFILTERSPARALLELGEOMETRY("vtkFiltersParallelGeometryJava", true),
+    VTKFILTERSPARALLELIMAGING("vtkFiltersParallelImagingJava", true),
     VTKFILTERSPARALLELMPI("vtkFiltersParallelMPIJava", true),
+    VTKFILTERSPARALLELSTATISTICS("vtkFiltersParallelStatisticsJava", true),
+    VTKFILTERSPOINTS("vtkFiltersPointsJava", true),
+    VTKFILTERSPROGRAMMABLE("vtkFiltersProgrammableJava", true),
+    VTKFILTERSPYTHON("vtkFiltersPythonJava", true),
+    VTKFILTERSREEBGRAPH("vtkFiltersReebGraphJava", true),
     VTKFILTERSSMP("vtkFiltersSMPJava", true),
-    VTKACCELERATORSDAX("vtkAcceleratorsDaxJava", false),
-    VTKACCELERATORSPISTON("vtkAcceleratorsPistonJava", false),
-    VTKPYTHONINTERPRETER("vtkPythonInterpreterJava", true),
-    VTKVIEWSINFOVIS("vtkViewsInfovisJava", true),
-    VTKVIEWSCORE("vtkViewsCoreJava", true),
-    VTKVIEWSGEOVIS("vtkViewsGeovisJava", true),
-    VTKVIEWSCONTEXT2D("vtkViewsContext2DJava", true),
-    VTKWEBCORE("vtkWebCoreJava", false),
-    VTKWEBGLEXPORTER("vtkWebGLExporterJava", false),
+    VTKFILTERSSELECTION("vtkFiltersSelectionJava", true),
+    VTKFILTERSSOURCES("vtkFiltersSourcesJava", true),
+    VTKFILTERSSTATISTICS("vtkFiltersStatisticsJava", true),
+    VTKFILTERSSTATISTICSGNUR("vtkFiltersStatisticsGnuRJava", false),
+    VTKFILTERSTEXTURE("vtkFiltersTextureJava", true),
+    VTKFILTERSVERDICT("vtkFiltersVerdictJava", true),
+    VTKGEOVISCORE("vtkGeovisCoreJava", true),
+    VTKIOADIOS("vtkIOADIOSJava", false),
+    VTKIOAMR("vtkIOAMRJava", true),
+    VTKIOCORE("vtkIOCoreJava", true),
+    VTKIOENSIGHT("vtkIOEnSightJava", true),
+    VTKIOEXODUS("vtkIOExodusJava", true),
+    VTKIOEXPORT("vtkIOExportJava", true),
+    VTKIOEXPORTOPENGL("vtkIOExportOpenGLJava", false),
+    VTKIOEXPORTOPENGL2("vtkIOExportOpenGL2Java", false),
+    VTKIOFFMPEG("vtkIOFFMPEGJava", true),
+    VTKIOGDAL("vtkIOGDALJava", true),
+    VTKIOGEOJSON("vtkIOGeoJSONJava", true),
+    VTKIOGEOMETRY("vtkIOGeometryJava", true),
+    VTKIOIMAGE("vtkIOImageJava", true),
+    VTKIOIMPORT("vtkIOImportJava", true),
+    VTKIOINFOVIS("vtkIOInfovisJava", true),
+    VTKIOLSDYNA("vtkIOLSDynaJava", true),
+    VTKIOLEGACY("vtkIOLegacyJava", true),
+    VTKIOMINC("vtkIOMINCJava", true),
+    VTKIOMPIIMAGE("vtkIOMPIImageJava", true),
+    VTKIOMPIPARALLEL("vtkIOMPIParallelJava", true),
+    VTKIOMOVIE("vtkIOMovieJava", true),
+    VTKIOMYSQL("vtkIOMySQLJava", true),
+    VTKIONETCDF("vtkIONetCDFJava", true),
+    VTKIOODBC("vtkIOODBCJava", true),
+    VTKIOPLY("vtkIOPLYJava", true),
+    VTKIOPARALLEL("vtkIOParallelJava", true),
+    VTKIOPARALLELEXODUS("vtkIOParallelExodusJava", true),
+    VTKIOPARALLELLSDYNA("vtkIOParallelLSDynaJava", true),
+    VTKIOPARALLELNETCDF("vtkIOParallelNetCDFJava", true),
+    VTKIOPARALLELXML("vtkIOParallelXMLJava", true),
+    VTKIOPOSTGRESQL("vtkIOPostgreSQLJava", true),
+    VTKIOSQL("vtkIOSQLJava", true),
+    VTKIOTECPLOTTABLE("vtkIOTecplotTableJava", true),
+    VTKIOVPIC("vtkIOVPICJava", true),
+    VTKIOVIDEO("vtkIOVideoJava", true),
+    VTKIOXML("vtkIOXMLJava", true),
+    VTKIOXMLPARSER("vtkIOXMLParserJava", true),
+    VTKIOXDMF2("vtkIOXdmf2Java", true),
+    VTKIOXDMF3("vtkIOXdmf3Java", true),
+    VTKIMAGINGCOLOR("vtkImagingColorJava", true),
+    VTKIMAGINGCORE("vtkImagingCoreJava", true),
+    VTKIMAGINGFOURIER("vtkImagingFourierJava", true),
+    VTKIMAGINGGENERAL("vtkImagingGeneralJava", true),
+    VTKIMAGINGHYBRID("vtkImagingHybridJava", true),
+    VTKIMAGINGMATH("vtkImagingMathJava", true),
+    VTKIMAGINGMORPHOLOGICAL("vtkImagingMorphologicalJava", true),
+    VTKIMAGINGOPENGL2("vtkImagingOpenGL2Java", false),
+    VTKIMAGINGSOURCES("vtkImagingSourcesJava", true),
+    VTKIMAGINGSTATISTICS("vtkImagingStatisticsJava", true),
+    VTKIMAGINGSTENCIL("vtkImagingStencilJava", true),
+    VTKINFOVISBOOSTGRAPHALGORITHMS("vtkInfovisBoostGraphAlgorithmsJava", true),
+    VTKINFOVISCORE("vtkInfovisCoreJava", true),
+    VTKINFOVISLAYOUT("vtkInfovisLayoutJava", true),
+    VTKINFOVISPARALLEL("vtkInfovisParallelJava", false),
+    VTKINTERACTIONIMAGE("vtkInteractionImageJava", true),
+    VTKINTERACTIONSTYLE("vtkInteractionStyleJava", true),
+    VTKINTERACTIONWIDGETS("vtkInteractionWidgetsJava", true),
     VTKPARALLELCORE("vtkParallelCoreJava", true),
     VTKPARALLELMPI("vtkParallelMPIJava", true),
     VTKPARALLELMPI4PY("vtkParallelMPI4PyJava", true),
-    VTKIOINFOVIS("vtkIOInfovisJava", true),
-    VTKIOPARALLELLSDYNA("vtkIOParallelLSDynaJava", true),
-    VTKIOSQL("vtkIOSQLJava", true),
-    VTKIOCORE("vtkIOCoreJava", true),
-    VTKIOLEGACY("vtkIOLegacyJava", true),
-    VTKIOENSIGHT("vtkIOEnSightJava", true),
-    VTKIOADIOS("vtkIOADIOSJava", false),
-    VTKIOMPIPARALLEL("vtkIOMPIParallelJava", true),
-    VTKIOGDAL("vtkIOGDALJava", true),
-    VTKIOIMPORT("vtkIOImportJava", true),
-    VTKIOGEOJSON("vtkIOGeoJSONJava", true),
-    VTKIOAMR("vtkIOAMRJava", true),
-    VTKIOPOSTGRESQL("vtkIOPostgreSQLJava", true),
-    VTKIOMOVIE("vtkIOMovieJava", true),
-    VTKIOPLY("vtkIOPLYJava", true),
-    VTKIOPARALLELXML("vtkIOParallelXMLJava", true),
-    VTKIOXDMF2("vtkIOXdmf2Java", true),
-    VTKIOMYSQL("vtkIOMySQLJava", true),
-    VTKIOFFMPEG("vtkIOFFMPEGJava", true),
-    VTKIOODBC("vtkIOODBCJava", true),
-    VTKIOMPIIMAGE("vtkIOMPIImageJava", true),
-    VTKIOPARALLELEXODUS("vtkIOParallelExodusJava", true),
-    VTKIOVPIC("vtkIOVPICJava", true),
-    VTKIOEXPORT("vtkIOExportJava", true),
-    VTKIOMINC("vtkIOMINCJava", true),
-    VTKIOVIDEO("vtkIOVideoJava", true),
-    VTKIOPARALLEL("vtkIOParallelJava", true),
-    VTKIOIMAGE("vtkIOImageJava", true),
-    VTKIOEXODUS("vtkIOExodusJava", true),
-    VTKIOXML("vtkIOXMLJava", true),
-    VTKIOXDMF3("vtkIOXdmf3Java", true),
-    VTKIONETCDF("vtkIONetCDFJava", true),
-    VTKIOXMLPARSER("vtkIOXMLParserJava", true),
-    VTKIOGEOMETRY("vtkIOGeometryJava", true),
-    VTKIOLSDYNA("vtkIOLSDynaJava", true),
-    VTKIOPARALLELNETCDF("vtkIOParallelNetCDFJava", true),
-    VTKTESTINGRENDERING("vtkTestingRenderingJava", true);
+    VTKRENDERINGANNOTATION("vtkRenderingAnnotationJava", true),
+    VTKRENDERINGCONTEXT2D("vtkRenderingContext2DJava", true),
+    VTKRENDERINGCONTEXTOPENGL("vtkRenderingContextOpenGLJava", false),
+    VTKRENDERINGCONTEXTOPENGL2("vtkRenderingContextOpenGL2Java", true),
+    VTKRENDERINGCORE("vtkRenderingCoreJava", true),
+    VTKRENDERINGEXTERNAL("vtkRenderingExternalJava", false),
+    VTKRENDERINGFREETYPE("vtkRenderingFreeTypeJava", true),
+    VTKRENDERINGGL2PS("vtkRenderingGL2PSJava", false),
+    VTKRENDERINGGL2PSOPENGL2("vtkRenderingGL2PSOpenGL2Java", true),
+    VTKRENDERINGIMAGE("vtkRenderingImageJava", true),
+    VTKRENDERINGLIC("vtkRenderingLICJava", false),
+    VTKRENDERINGLICOPENGL2("vtkRenderingLICOpenGL2Java", true),
+    VTKRENDERINGLOD("vtkRenderingLODJava", true),
+    VTKRENDERINGLABEL("vtkRenderingLabelJava", true),
+    VTKRENDERINGMATPLOTLIB("vtkRenderingMatplotlibJava", true),
+    VTKRENDERINGOSPRAY("vtkRenderingOSPRayJava", false),
+    VTKRENDERINGOCULUS("vtkRenderingOculusJava", false),
+    VTKRENDERINGOPENGL("vtkRenderingOpenGLJava", false),
+    VTKRENDERINGOPENGL2("vtkRenderingOpenGL2Java", true),
+    VTKRENDERINGOPENVR("vtkRenderingOpenVRJava", false),
+    VTKRENDERINGPARALLEL("vtkRenderingParallelJava", true),
+    VTKRENDERINGPARALLELLIC("vtkRenderingParallelLICJava", true),
+    VTKRENDERINGQT("vtkRenderingQtJava", true),
+    VTKRENDERINGSCENEGRAPH("vtkRenderingSceneGraphJava", true),
+    VTKRENDERINGVOLUME("vtkRenderingVolumeJava", true),
+    VTKRENDERINGVOLUMEAMR("vtkRenderingVolumeAMRJava", true),
+    VTKRENDERINGVOLUMEOPENGL("vtkRenderingVolumeOpenGLJava", false),
+    VTKRENDERINGVOLUMEOPENGL2("vtkRenderingVolumeOpenGL2Java", true),
+    VTKTESTINGRENDERING("vtkTestingRenderingJava", true),
+    VTKPYTHONINTERPRETER("vtkPythonInterpreterJava", true),
+    VTKVIEWSCONTEXT2D("vtkViewsContext2DJava", true),
+    VTKVIEWSCORE("vtkViewsCoreJava", true),
+    VTKVIEWSGEOVIS("vtkViewsGeovisJava", true),
+    VTKVIEWSINFOVIS("vtkViewsInfovisJava", true),
+    VTKWEBCORE("vtkWebCoreJava", false),
+    VTKWEBGLEXPORTER("vtkWebGLExporterJava", false);
 
 
   /**
