@@ -15,6 +15,14 @@ public class vtkTypeFloat32Array extends vtkFloatArray
   public int IsA(String id0)
     { return IsA_1(id0); }
 
+  private native long FastDownCast_2(vtkAbstractArray id0);
+  public vtkTypeFloat32Array FastDownCast(vtkAbstractArray id0) {
+    long temp = FastDownCast_2(id0);
+
+    if (temp == 0) return null;
+    return (vtkTypeFloat32Array)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
+}
+
   public vtkTypeFloat32Array() { super(); }
 
   public vtkTypeFloat32Array(long id) { super(id); }
