@@ -15,6 +15,14 @@ public class vtkTypeInt8Array extends vtkSignedCharArray
   public int IsA(String id0)
     { return IsA_1(id0); }
 
+  private native long FastDownCast_2(vtkAbstractArray id0);
+  public vtkTypeInt8Array FastDownCast(vtkAbstractArray id0) {
+    long temp = FastDownCast_2(id0);
+
+    if (temp == 0) return null;
+    return (vtkTypeInt8Array)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
+}
+
   public vtkTypeInt8Array() { super(); }
 
   public vtkTypeInt8Array(long id) { super(id); }
