@@ -15,6 +15,14 @@ public class vtkTypeUInt64Array extends vtkUnsignedLongLongArray
   public int IsA(String id0)
     { return IsA_1(id0); }
 
+  private native long FastDownCast_2(vtkAbstractArray id0);
+  public vtkTypeUInt64Array FastDownCast(vtkAbstractArray id0) {
+    long temp = FastDownCast_2(id0);
+
+    if (temp == 0) return null;
+    return (vtkTypeUInt64Array)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
+}
+
   public vtkTypeUInt64Array() { super(); }
 
   public vtkTypeUInt64Array(long id) { super(id); }
